<?php

/* 
 * Themez Kitchen
 * -----------------------------------------------------------
 * @package Premium Multipurpose WordPress Theme
 * @subpackage ThemezKitchen
 * @copyright Copyright (c), ThemezKitchen,  (http://www.themezkitchen.com/)
 * @link http://www.themezkitchen.com/
 * @version 1.0.0
 * @since Version 1.0.0
 */

/**
 * Back Compatibility function for users who doesn't have the WordPress 4.0 installed
 */
/**
 * Prevent switching to an on old versions of WordPress.
 * Switches to the default theme.
 * @since  1.0.0
 */
function allspice_switch_theme() {
	switch_theme( WP_DEFAULT_THEME, WP_DEFAULT_THEME );
	unset( $_GET['activated'] );
	add_action( 'admin_notices', 'allspice_upgrade_notice' );
}
add_action( 'after_switch_theme', 'allspice_switch_theme' );

/**
 * Add message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * WP versions prior to 4.0.
 *
 * @since 1.0.0
 */
function allspice_upgrade_notice() {
	$message = sprintf( __( 'This theme requires at least WordPress version 4.0. You are running version %s. Please upgrade and try again.', 'allspice' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

/**
 * Prevent the Theme Preview from being loaded on WordPress versions prior to 4.0.
 *
 * @since 1.0.0
 */
function allspice_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( __( 'This theme requires at least WordPress version 4.0. You are running version %s. Please upgrade and try again.', 'allspice' ), $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'allspice_preview' );


/**
 * Prevent the Theme Customizer from being loaded on WordPress versions prior to 4.0
 *
 * @since 1.0.0
 */
function allspice_customize() {
	wp_die( sprintf( __( 'This theme requires at least WordPress version 4.0. You are running version %s. Please upgrade and try again.', 'allspice' ), $GLOBALS['wp_version'] ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'allspice_customize' );