<?php

/*
 * Themez Kitchen
 * -----------------------------------------------------------
 * @package Themez Kitchen  - Premium Multipurpose WordPress Themess
 * @subpackage ThemezKitchen
 * @copyright Copyright (c), ThemezKitchen,  (http://www.themezkitchen.com/)
 * @link http://www.themezkitchen.com/
 * @version 1.0.0
 * @since Version 1.0.0
 */

/**
 * Implement Theme Customizer additions and adjustments.
 *
 * @since 1.0.0
 */
function allspice_customize_register($wp_customize) {
    // Add custom description to Colors and Background sections.
    $wp_customize->get_section('colors')->description = __('Background may only be visible on wide screens.', 'allspice');
    $wp_customize->get_section('background_image')->description = __('Background Pattern may only be visible on wide screens.', 'allspice');

    // Add the content settings (layout)
    $wp_customize->add_section('layout_settings', array(
        'title' => __('Site Settings', 'allspice'),
        'description' => sprintf(__('Choose the layout of your blog', 'allspice')
        ),
        'priority' => 130,
    ));

    // Add the featured content layout setting and control.
    $wp_customize->add_setting('content_layout', array(
        'default' => 'left',
        'sanitize_callback' => 'allspice_sanitize_layout',
    ));

    $wp_customize->add_control('content_layout', array(
        'label' => __('Layout', 'allspice'),
        'section' => 'layout_settings',
        'type' => 'select',
        'choices' => array(
            'left' => __('Left Sidebar', 'allspice'),
            'right' => __('Right Sidebar', 'allspice'),
            'None' => __('No Sidebar', 'allspice'),
        ),
    ));
    
    // Add the featured content layout setting and control.
    $wp_customize->add_setting('facebook_url', array(
        'default' => 'http://www.facebook.com',
        'sanitize_callback' => 'esc_url_raw',
    ));
    
    $wp_customize->add_control('facebook_url', array(
        'label' => __('Facebook Page', 'allspice'),
        'section' => 'layout_settings',
        'type' => 'text'
    ));
    
    $wp_customize->add_setting('twitter_url', array(
        'default' => 'http://twitter.com',
        'sanitize_callback' => 'esc_url_raw',
    ));
    
    $wp_customize->add_control('twitter_url', array(
        'label' => __('Twitter Profile', 'allspice'),
        'section' => 'layout_settings',
        'type' => 'text'
    ));
    
    $wp_customize->add_setting('pinterest_url', array(
        'default' => 'http://pinterest.com',
        'sanitize_callback' => 'esc_url_raw',
    ));
    
    $wp_customize->add_control('pinterest_url', array(
        'label' => __('Pinterest Profile', 'allspice'),
        'section' => 'layout_settings',
        'type' => 'text'
    ));
    
    $wp_customize->add_setting('google_url', array(
        'default' => 'http://www.google.com',
        'sanitize_callback' => 'esc_url_raw',
    ));
    
    $wp_customize->add_control('google_url', array(
        'label' => __('Google+ Page', 'allspice'),
        'section' => 'layout_settings',
        'type' => 'text'
    ));
    
    $wp_customize->add_setting( 'header_image', array(
        'default' => null,
        'sanitize_callback' => 'esc_url_raw',
    ));
    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'header_image', array(
    'label'    => __( 'Header Background Image', 'allspice' ),
    'section'  => 'layout_settings',
    'settings' => 'header_image',
) ) );
   
}

add_action('customize_register', 'allspice_customize_register');

/**
 * Sanitize the Content layout value.
 */
function allspice_sanitize_layout($layout) {
    if (!in_array($layout, array('left', 'right', 'None'))) {
        $layout = 'left';
    }

    return $layout;
}
