<?php

/*
 * Themez Kitchen
 * -----------------------------------------------------------
 * @package Themez Kitchen  - Premium Multipurpose WordPress Theme
 * @subpackage ThemezKitchen
 * @copyright Copyright (c), ThemezKitchen,  (http://www.themezkitchen.com/)
 * @link http://www.themezkitchen.com/
 * @version 1.0.0
 * @since Version 1.0.0
 */

/**
 * Blog functions
 */
if (!function_exists('allspice_posted_on')) :

    /**
     * Print HTML with meta information for the current post-date/time
     *
     * @since 1.0.0
     */
    function allspice_posted_on() {
        // Set up and print post meta information.
        printf( '<span class="entry-date"><a href="%1$s"><time class="entry-date" datetime="%2$s">%3$s</time></a></span>',
                esc_url( get_the_permalink() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() )
	);
        
	printf( ' | <span class="byline"><span class="author vcard"><a class="url fn n" href="%1$s" rel="author">%2$s</a></span></span>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		get_the_author()
	);
    }

endif;



if (!function_exists('allspice_allowedtags')) :

    /**
     * Allowed tags on the excerpt
     * @return string
     */
    function allspice_allowedtags() {
        // Add custom tags to this string
        //return '<script>,<style>,<br>,<em>,<i>,<ul>,<ol>,<li>,<a>,<p>,<img>,<video>,<audio>';
        return '';
    }

endif;

if (!function_exists('allspice_custom_excerpt')) :

    /**
     * Custom excerpt function
     * @global type $post
     * @param type $allspice_excerpt
     * @return string
     * @since 1.0.0
     */
    function allspice_custom_excerpt($allspice_excerpt = '') {
        global $post;
        $raw_excerpt = $allspice_excerpt;
        if ($allspice_excerpt == '') {
            $allspice_excerpt = get_the_content('');
            $allspice_excerpt = strip_shortcodes($allspice_excerpt);
            $allspice_excerpt = apply_filters('the_content', $allspice_excerpt);
            $allspice_excerpt = str_replace(']]>', ']]&gt;', $allspice_excerpt);
            $allspice_excerpt = preg_replace('/\b(https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|$!:,.;]*[A-Z0-9+&@#\/%=~_|$]/i', '', $allspice_excerpt);
            $allspice_excerpt = strip_tags($allspice_excerpt, allspice_allowedtags()); /* IF you need to allow just certain tags. Delete if all tags are allowed */

            //Set the excerpt word count and only break after sentence is complete.
            $excerpt_word_count = 30;
            $excerpt_length = apply_filters('excerpt_length', $excerpt_word_count);
            $tokens = array();
            $excerptOutput = '';
            $count = 0;

            // Divide the string into tokens; HTML tags, or words, followed by any whitespace
            preg_match_all('/(<[^>]+>|[^<>\s]+)\s*/u', $allspice_excerpt, $tokens);

            foreach ($tokens[0] as $token) {

                if ($count >= $excerpt_word_count && preg_match('/[\,\;\?\.\!]\s*$/uS', $token)) {
                    // Limit reached, continue until , ; ? . or ! occur at the end
                    $excerptOutput .= trim($token);
                    break;
                }

                // Add words to complete sentence
                $count++;

                // Append what's left of the token
                $excerptOutput .= $token;
            }

            $allspice_excerpt = trim(force_balance_tags($excerptOutput));


            $excerpt_end = '...';
            $excerpt_more = apply_filters('excerpt_more', ' ' . $excerpt_end);

            //$pos = strrpos($allspice_excerpt, '</');
            //if ($pos !== false)
            // Inside last HTML tag
            //$allspice_excerpt = substr_replace($allspice_excerpt, $excerpt_end, $pos, 0); /* Add read more next to last word */
            //else
            // After the content
            $allspice_excerpt .= $excerpt_end; /* Add read more in new paragraph */

            return trim($allspice_excerpt);
        }
        return apply_filters('allspice_custom_excerpt', $allspice_excerpt, $raw_excerpt);
    }

endif;

remove_filter('get_the_excerpt', 'wp_trim_excerpt');
add_filter('get_the_excerpt', 'allspice_custom_excerpt');


/**
 * Find out if blog has more than one category.
 * @since  1.0.0
 * @return boolean
 */
function allspice_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'allspice_category_count' ) ) ) {
		$all_the_cool_cats = get_categories( array(
			'hide_empty' => 1,
		) );
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'allspice_category_count', $all_the_cool_cats );
	}

	if ( 1 !== (int) $all_the_cool_cats ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Flush out the transients used in twentyfourteen_categorized_blog.
 *
 * @since 1.0.0
 */
function allspice_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'allspice_category_count' );
}
add_action( 'edit_category', 'allspice_category_transient_flusher' );
add_action( 'save_post',     'allspice_category_transient_flusher' );