<?php
/*
 * Themez Kitchen
 * -----------------------------------------------------------
 * @package Themez Kitchen  - Premium Multipurpose WordPress Theme
 * @subpackage ThemezKitchen
 * @copyright Copyright (c), ThemezKitchen,  (http://www.themezkitchen.com/)
 * @link http://www.themezkitchen.com/
 * @version 1.0.0
 * @since Version 1.0.0
 */

/**
 * Filter the page menu arguments.
 *
 * Makes our wp_nav_menu() fallback -- wp_page_menu() -- show a home link.
 *
 * @since 1.0.0
 */
function allspice_page_menu_args($args) {
    if (!isset($args['show_home']))
        $args['show_home'] = true;
    return $args;
}

add_filter('wp_page_menu_args', 'allspice_page_menu_args');

/**
 * Register Google Font for the Theme.
 * @since 1.0.0
 * @return string
 */
function allspice_font_url() {
    $font_url = '';
    /*
     * Translators: If there are characters in your language that are not supported
     * by the theme Google font, translate this to 'off'. Do not translate into your own language.
     */
    if ('off' !== _x('on', 'Google font: on or off', 'allspice')) {
        $font_url = add_query_arg('family', urlencode('Roboto:300,400,700|Merriweather'), "//fonts.googleapis.com/css");
    }
    return $font_url;
}

/**
 * Enqueue scripts and styles for the front end.
 * @since 1.0.0
 */
function allspice_scripts() {
    // Load our main stylesheet
    // Add Google font, used in the main stylesheet.
    wp_enqueue_style('wk-google-font', allspice_font_url(), array(), null);
    wp_enqueue_style('wk-template', get_template_directory_uri() . '/css/template.css', array(), '1.0.1');
    // Load our main stylesheet (WP default)
    wp_enqueue_style('wk-template-style', get_stylesheet_uri(), array('wk-template'));
    wp_enqueue_style('wk-lightbox', get_template_directory_uri() . '/css/lightbox.css', array('wk-template', 'wk-template-style'));

    //Also we must add our color scheme based on the theme settings
    //Take a peek into the css/schemes folder and include the scheme you like
    wp_enqueue_style('wk-color-scheme', get_template_directory_uri() . '/css/schemes/dark.css', array('wk-template', 'wk-template-style', 'wk-lightbox'));

    // Load the user overrides stylesheet
    wp_enqueue_style('wk-template-overrides', get_template_directory_uri() . '/css/user.css', array('wk-template', 'wk-template-style', 'wk-lightbox', 'wk-color-scheme'), time());

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
    //include JS
    wp_enqueue_script('bootstrap-scripts', get_template_directory_uri() . '/js/vendor/bootstrap.min.js', array('jquery'), '1.0.0', true);
    wp_enqueue_script('wk-waypoints', get_template_directory_uri() . '/js/vendor/waypoints.min.js', array('jquery'), '1.0.0', true);
    wp_enqueue_script('wk-lightbox', get_template_directory_uri() . '/js/vendor/lightbox.min.js', array('jquery'), '1.0.0', true);
    wp_enqueue_script('wk-scripts', get_template_directory_uri() . '/js/functions.js', array('jquery'), '1.0.1', true);
}

add_action('wp_enqueue_scripts', 'allspice_scripts');

/**
 * Add HTML SHIM and Respond.js form CDN
 */
function allspice_add_shim() {
    echo '<!--[if lt IE 9]>'
    . "\n" . '<script src="' . get_template_directory_uri() . '/js/html5shiv.min.js"></script>'
    . "\n" . '<script src="' . get_template_directory_uri() . '/js/respond.min.js"></script>'
    . "\n" . '<![endif]-->';
}

add_action('wp_head', 'allspice_add_shim');

/**
 * Add Custom Header BG
 */
function allspice_add_headerbg() {
    if (get_theme_mod('header_image') != null) :
    echo '<style type="text/css">'
    . "\n" . '.author-cover { background-image: url(' . esc_url(get_theme_mod('header_image')) . ');}'
    . "\n" . '</style>';
    endif;
}

add_action('wp_head', 'allspice_add_headerbg');

/**
 * Extend the default WordPress body classes.
 * Adds body classes to denote:
 * 1. Single or multiple authors.
 * 2. Active widgets in the sidebar to change the layout and spacing.
 * 3. When avatars are disabled in discussion settings.
 * @since 1.0.0
 * @param array $classes
 * @return array
 */
function allspice_body_class($classes) {
    if (!is_multi_author()) {
        $classes[] = 'single-author';
    }


    if (is_active_sidebar('sidebar-primary') && !is_attachment() && !is_404()) {
        $classes[] = 'sidebar';
    }


    if (!get_option('show_avatars')) {
        $classes[] = 'no-avatars';
    }


    if (is_archive() || is_search() || is_home()) {
        $classes[] = 'list-view';
    }

    if (is_singular() && !is_front_page()) {
        $classes[] = 'singular';
    }

    return $classes;
}

add_filter('body_class', 'allspice_body_class');

/**
 * Extend the default WordPress post classes.
 * Adds a post class to denote:
 * Non-password protected page with a post thumbnail.
 * @since 1.0.0
 * @param array $classes
 * @return array
 */
function allspice_post_classes($classes) {
    if (!post_password_required() && !is_attachment() && has_post_thumbnail()) {
        $classes[] = 'has-post-thumbnail';
    }
    return $classes;
}

add_filter('post_class', 'allspice_post_classes');

/**
 * return $images_id array()
 */
function allspice_get_gallery_attachments() {
    global $post;
    $post_content = $post->post_content;
    $ids = array();
    preg_match('/\[gallery.*ids=.(.*).\]/', $post_content, $ids);
    if (!empty($ids)) :
        $images_id = explode(",", $ids[1]);
    else :
        $images_id = array();
    endif;
    return $images_id;
}

/**
 * Strip shortcode gallery
 * @param type $content
 * @return type
 */
function allspice_strip_shortcode_gallery($content) {
    preg_match_all('/' . get_shortcode_regex() . '/s', $content, $matches, PREG_SET_ORDER);
    if (!empty($matches)) {
        foreach ($matches as $shortcode) {
            if ('gallery' === $shortcode[2]) {
                $pos = strpos($content, $shortcode[0]);
                if ($pos !== false)
                    return substr_replace($content, '', $pos, strlen($shortcode[0]));
            }
        }
    }
    return $content;
}


/**
 * Get attachment meta data
 * @param type $attachment_id
 * @return type
 * @since 1.0.0
 */
function allspice_get_attachment($attachment_id) {

    $attachment = get_post($attachment_id);
    return array(
        'alt' => get_post_meta($attachment->ID, '_wp_attachment_image_alt', true),
        'caption' => $attachment->post_excerpt,
        'description' => $attachment->post_content,
        'href' => get_permalink($attachment->ID),
        'src' => $attachment->guid,
        'title' => $attachment->post_title
    );
}

if (!function_exists('allspice_posts_navigation')) :

    /**
     * Display navigation to next/previous post when applicable.
     * @since 1.0.0
     */
    function allspice_posts_navigation() {
        // Don't print empty markup if there's nowhere to navigate.
        $previous = ( is_attachment() ) ? get_post(get_post()->post_parent) : get_adjacent_post(false, '', true);
        $next = get_adjacent_post(false, '', false);
        if (!$next && !$previous) {
            return;
        }
        ?>
        <nav class="allspice_navigation post-navigation" role="navigation">
            <h1 class="sr-only sr-only-focusable"><?php _e('Post navigation', 'allspice'); ?></h1>
            <div class="nav-links row">
                <?php
                if (is_attachment()) :
                    previous_post_link('%link', __('<div class="col-md-12"><span class="meta-nav">Published In</span>%title</div>', 'allspice'));
                else :
                    previous_post_link('%link', __('<div class="col-xs-6"><div class="pull-left icon"><i class="fa fa-chevron-left"></i></div><div class="nav-body hidden-xs"><span class="meta-nav">Previous Post</span>%title</div></div>', 'allspice'));
                    next_post_link('%link', __('<div class="col-xs-6 text-right"><div class="pull-right icon"><i class="fa fa-chevron-right"></i></div><div class="nav-body hidden-xs"><span class="meta-nav">Next Post</span>%title</div></div>', 'allspice'));
                endif;
                ?>
            </div><!-- .nav-links -->
        </nav><!-- .navigation -->
        <?php
    }

endif;



if (!function_exists('allspice_paging_nav')) :

    /**
     * Display navigation to next/previous set of posts when applicable.
     *
     * @since 1.0.0
     *
     * @global WP_Query
     * @global WP_Rewrite
     */
    function allspice_paging_nav() {
        global $wp_query, $wp_rewrite;

        // Don't print empty markup if there's only one page.
        if ($wp_query->max_num_pages < 2) {
            return;
        }

        $paged = get_query_var('paged') ? intval(get_query_var('paged')) : 1;
        $pagenum_link = html_entity_decode(get_pagenum_link());
        $query_args = array();
        $url_parts = explode('?', $pagenum_link);

        if (isset($url_parts[1])) {
            wp_parse_str($url_parts[1], $query_args);
        }

        $pagenum_link = remove_query_arg(array_keys($query_args), $pagenum_link);
        $pagenum_link = trailingslashit($pagenum_link) . '%_%';

        $format = $wp_rewrite->using_index_permalinks() && !strpos($pagenum_link, 'index.php') ? 'index.php/' : '';
        $format .= $wp_rewrite->using_permalinks() ? user_trailingslashit($wp_rewrite->pagination_base . '/%#%', 'paged') : '?paged=%#%';

        // Set up paginated links.
        $links = paginate_links(array(
            'base' => $pagenum_link,
            'format' => $format,
            'total' => $wp_query->max_num_pages,
            'current' => $paged,
            'mid_size' => 1,
            'add_args' => array_map('urlencode', $query_args),
            'prev_text' => __('<i class="fa fa-chevron-left"></i> Previous', 'allspice'),
            'next_text' => __('Next <i class="fa fa-chevron-right"></i>', 'allspice'),
        ));

        if ($links) :
            ?>
            <nav class="navigation paging-navigation" role="navigation">
                <h1 class="sr-only sr-only-focusable"><?php _e('Posts navigation', 'allspice'); ?></h1>
                <div class="pagination loop-pagination">
                    <?php echo $links; ?>
                </div><!-- .pagination -->
            </nav><!-- .navigation -->
            <?php
        endif;
    }

endif;

/**
 * Theme copyright text 
 * @since 1.0.0
 */
function allspice_copyright() {
        printf(__('Copyright &copy; %s Allspice Theme by', 'allspice'), date("Y")); ?> 
        <a href="<?php echo esc_url(__('http://www.themezkitchen.com/', 'allspice')); ?>"><?php _e('Themez Kitchen', 'allspice'); ?></a> |
        <?php _e('All Rights Reserved', 'allspice'); ?> | 
        <a href="<?php echo esc_url(__('http://WordPress.org/', 'allspice')); ?>"><?php printf(__('Proudly powered by %s', 'allspice'), 'WordPress'); ?></a>
    <?php
}

/**
 * Social buttons
 */
function allspice_social() {
    ?>
    <div class="wk-social-icons">
        <?php if (get_theme_mod('facebook_url') != '') : ?>
            <a href="<?php echo esc_url(get_theme_mod('facebook_url')); ?>"><i class="fa fa-facebook"></i></a> 
        <?php endif; ?>
        <?php if (get_theme_mod('twitter_url') != '') : ?>
            <a href="<?php echo esc_url(get_theme_mod('twitter_url'));?>"><i class="fa fa-twitter"></i></a> 
        <?php endif; ?>
        <?php if (get_theme_mod('google_url') != '') : ?>
            <a href="<?php echo esc_url(get_theme_mod('google_url'));?>"><i class="fa fa-google-plus"></i></a> 
        <?php endif; ?>
        <?php if (get_theme_mod('pinterest_url') != '') : ?>
            <a href="<?php echo esc_url(get_theme_mod('pinterest_url'));?>"><i class="fa fa-pinterest"></i></a>  
        <?php endif; ?>
    </div>
    <?php
}

if (!function_exists('allspice_share')) :

    /**
     * Social buttons
     */
    function allspice_share() {
        global $post;
        ?>
        <div class="wk-share-icons text-center">
            <a href="#" data-href="http://www.facebook.com/sharer.php?m2w&amp;s=100&amp;p[url]=<?php echo rawurlencode(get_the_permalink()); ?>&amp;p[images][0]=<?php echo wp_get_attachment_url(get_post_thumbnail_id()); ?>&amp;p[title]=<?php echo rawurlencode(get_the_title()); ?>"><i class="fa fa-facebook"></i><span class="sr-only"><?php _e('Facebook', 'allspice'); ?></span></a>
            <a href="#" data-href="http://twitter.com/home?status=<?php echo rawurlencode(get_the_title()); ?>%20%20<?php echo rawurlencode(get_the_permalink()); ?>"><i class="fa fa-twitter"></i><span class="sr-only"><?php _e('Twitter', 'allspice'); ?></span></a>
            <a href="#" data-href="http://pinterest.com/pin/create/button/?url=<?php echo rawurlencode(get_the_permalink()); ?>>&amp;description=<?php echo rawurlencode(get_the_title()); ?>&amp;media=<?php echo wp_get_attachment_url(get_post_thumbnail_id()); ?>"><i class="fa fa-pinterest"></i><span class="sr-only"><?php _e('Pinterest', 'allspice'); ?></span></a>
            <a href="#" data-href="https://plus.google.com/share?url=<?php echo rawurlencode(get_the_permalink()); ?>%22%20onclick=%22javascript:window.open(this.href,%27%27,%20%27menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600%27);return%20false;"><i class="fa fa-google-plus"></i><span class="sr-only"><?php _e('Google +', 'allspice'); ?></span></a>
        </div>
        <?php
    }

endif;


if (!function_exists('allspice_share_side')) :

    /**
     * Social buttons
     */
    function allspice_share_side() {
        global $post;
        ?>
        <span class="sr-only"><?php _e('Share this article', 'allspice'); ?></span>
        <ul class="wk-share-side-icons list-unstyled hidden-xs">
            <li><a href="#" data-href="http://www.facebook.com/sharer.php?m2w&amp;s=100&amp;p[url]=<?php echo rawurlencode(get_the_permalink()); ?>&amp;p[images][0]=<?php echo wp_get_attachment_url(get_post_thumbnail_id()); ?>&amp;p[title]=<?php echo rawurlencode(get_the_title()); ?>"><i class="fa fa-facebook"></i><span class="sr-only"><?php _e('Facebook', 'allspice'); ?></span></a></li>
            <li><a href="#" data-href="http://twitter.com/home?status=<?php echo rawurlencode(get_the_title()); ?>%20%20<?php echo rawurlencode(get_the_permalink()); ?>"><i class="fa fa-twitter"></i><span class="sr-only"><?php _e('Twitter', 'allspice'); ?></span></a></li>
            <li><a href="#" data-href="http://pinterest.com/pin/create/button/?url=<?php echo rawurlencode(get_the_permalink()); ?>&amp;description=<?php echo rawurlencode(get_the_title()); ?>&amp;media=<?php echo wp_get_attachment_url(get_post_thumbnail_id()); ?>"><i class="fa fa-pinterest"></i><span class="sr-only"><?php _e('Pinterest', 'allspice'); ?></span></a></li>
            <li><a href="#" data-href="https://plus.google.com/share?url=<?php echo rawurlencode(get_the_permalink()); ?>%22%20onclick=%22javascript:window.open(this.href,%27%27,%20%27menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600%27);return%20false;"><i class="fa fa-google-plus"></i><span class="sr-only"><?php _e('Google +', 'allspice'); ?></span></a></li>
        </ul>
        <?php
    }

endif;


if (!function_exists('allspice_the_attached_image')) :

    /**
     * Print the attached image with a link to the next attached image.
     *
     * @since 1.0.0
     */
    function allspice_the_attached_image() {
        $post = get_post();
        $attachment_size = apply_filters('allspice_attachment_size', array(950, 445));
        $next_attachment_url = wp_get_attachment_url();

        $attachment_ids = get_posts(array(
            'post_parent' => $post->post_parent,
            'fields' => 'ids',
            'numberposts' => -1,
            'post_status' => 'inherit',
            'post_type' => 'attachment',
            'post_mime_type' => 'image',
            'order' => 'ASC',
            'orderby' => 'menu_order ID',
        ));

        // If there is more than 1 attachment in a gallery...
        if (count($attachment_ids) > 1) {
            foreach ($attachment_ids as $attachment_id) {
                if ($attachment_id == $post->ID) {
                    $next_id = current($attachment_ids);
                    break;
                }
            }

            // get the URL of the next image attachment...
            if ($next_id) {
                $next_attachment_url = get_attachment_link($next_id);
            }

            // or get the URL of the first image attachment.
            else {
                $next_attachment_url = get_attachment_link(array_shift($attachment_ids));
            }
        }

        printf('<a href="%1$s" rel="attachment" class="thumbnail-link"><span class="thumbnail-overlay"></span>%2$s</a>', esc_url($next_attachment_url), wp_get_attachment_image($post->ID, $attachment_size)
        );
    }






endif;